@@ -25,14 +25,21 @@ CONTACT_MAILING_STATUS = (
 )
 
 
+def get_default_mainlist():
+    ids = MailingList.objects.values_list('id', flat=True)
+    if len(ids) == 1:
+        return ids
+    return []
+
 class Contact(models.Model):
-    email = models.EmailField(_('e-mail'), unique=True)
     first_name = models.CharField(_('first name'), max_length=64, blank=True)
     last_name = models.CharField(_('last name'), max_length=64, blank=True)
+    email = models.EmailField(_('e-mail'), unique=True)
     mailing_lists = models.ManyToManyField(
         'informativo.MailingList',
         verbose_name=_('mailing lists'),
-        related_name='subscribers'
+        related_name='subscribers',
+        default=get_default_mainlist
     )
 
     class Meta:
